@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for datapipeline service client paginators.
 
@@ -20,9 +21,10 @@ Usage::
     query_objects_paginator: QueryObjectsPaginator = client.get_paginator("query_objects")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_datapipeline.type_defs import (
     DescribeObjectsOutputTypeDef,
     ListPipelinesOutputTypeDef,
@@ -31,13 +33,12 @@ from mypy_boto3_datapipeline.type_defs import (
     QueryTypeDef,
 )
 
-
 __all__ = ("DescribeObjectsPaginator", "ListPipelinesPaginator", "QueryObjectsPaginator")
 
 
 class DescribeObjectsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeObjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
+    [Paginator.DescribeObjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
     """
 
     def paginate(
@@ -48,26 +49,26 @@ class DescribeObjectsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeObjectsOutputTypeDef]:
         """
-        [DescribeObjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects.paginate)
+        [DescribeObjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects.paginate)
         """
 
 
 class ListPipelinesPaginator(Boto3Paginator):
     """
-    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
+    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListPipelinesOutputTypeDef]:
         """
-        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines.paginate)
+        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines.paginate)
         """
 
 
 class QueryObjectsPaginator(Boto3Paginator):
     """
-    [Paginator.QueryObjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
+    [Paginator.QueryObjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
     """
 
     def paginate(
@@ -78,5 +79,5 @@ class QueryObjectsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[QueryObjectsOutputTypeDef]:
         """
-        [QueryObjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects.paginate)
+        [QueryObjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects.paginate)
         """
